VASP Workflow Library
--------------------

This module defines settings for common VASP workflows. Because workflows are primarily just the pairing of tasks with database tables, many of the workflows here have very little code associated with them. If you instead wish to see the settings used by a given workflow, you should follow it's linked `S3Task` to the `simmate.calculators.vasp.tasks` module.
